@@ -2,16 +2,13 @@
 Build manifest with kustomize
 """
 from ..helpers.binaries import binarypath, shell
-from ..helpers.download import ensure_binary
 
 
 def build(folders, edit):
     """
     Build manifests with kustomize
     """
-    ensure_binary('kustomize')
-
-    kustomize = binarypath('kustomize')
+    kustomize = binarypath('kustomize', download_if_missing=True)
     folder_list = ' '.join(folders)
     exec_string = f"{kustomize} build {folder_list}"
 
